/****************************************************************************
** Meta object code from reading C++ file 'accountconfiguration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmail-account-wizard-26.07.90/src/accountconfiguration.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountconfiguration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20AccountConfigurationE_t {};
} // unnamed namespace

template <> constexpr inline auto AccountConfiguration::qt_create_metaobjectdata<qt_meta_tag_ZN20AccountConfigurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AccountConfiguration",
        "QML.Element",
        "auto",
        "passwordChanged",
        "",
        "emailChanged",
        "identityChanged",
        "configurationIsValidChanged",
        "incomingHostNameChanged",
        "incomingPortChanged",
        "incomingUserNameChanged",
        "incomingProtocolChanged",
        "incomingSecurityProtocolChanged",
        "incomingAuthenticationProtocolChanged",
        "disconnectedModeEnabledChanged",
        "hasDisconnectedModeChanged",
        "error",
        "msg",
        "info",
        "finished",
        "serverTestInProgressModeChanged",
        "save",
        "ConsoleLog*",
        "consoleLog",
        "checkServer",
        "checkConfiguration",
        "mailTransport",
        "MailTransport::Transport*",
        "identity",
        "KIdentityManagementCore::Identity",
        "password",
        "email",
        "incomingHostName",
        "incomingPort",
        "incomingUserName",
        "configurationIsValid",
        "incomingProtocol",
        "IncomingProtocol",
        "incomingSecurityProtocol",
        "MailTransport::Transport::EnumEncryption",
        "incomingAuthenticationProtocol",
        "MailTransport::Transport::EnumAuthenticationType",
        "disconnectedModeEnabled",
        "hasDisconnectedMode",
        "serverTestInProgress",
        "IMAP",
        "POP3",
        "KOLAB"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'passwordChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emailChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationIsValidChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incomingHostNameChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incomingPortChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incomingUserNameChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incomingProtocolChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incomingSecurityProtocolChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incomingAuthenticationProtocolChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disconnectedModeEnabledChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasDisconnectedModeChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'serverTestInProgressModeChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'save'
        QtMocHelpers::MethodData<void(ConsoleLog *)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'checkServer'
        QtMocHelpers::MethodData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'checkConfiguration'
        QtMocHelpers::MethodData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mailTransport'
        QtMocHelpers::PropertyData<MailTransport::Transport*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'identity'
        QtMocHelpers::PropertyData<KIdentityManagementCore::Identity>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'password'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'email'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'incomingHostName'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'incomingPort'
        QtMocHelpers::PropertyData<uint>(33, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'incomingUserName'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'configurationIsValid'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Final, 3),
        // property 'incomingProtocol'
        QtMocHelpers::PropertyData<enum IncomingProtocol>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7),
        // property 'incomingSecurityProtocol'
        QtMocHelpers::PropertyData<MailTransport::Transport::EnumEncryption>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 8),
        // property 'incomingAuthenticationProtocol'
        QtMocHelpers::PropertyData<MailTransport::Transport::EnumAuthenticationType>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 9),
        // property 'disconnectedModeEnabled'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 10),
        // property 'hasDisconnectedMode'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Final, 11),
        // property 'serverTestInProgress'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Final, 15),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'IncomingProtocol'
        QtMocHelpers::EnumData<enum IncomingProtocol>(37, 37, QMC::EnumFlags{}).add({
            {   45, IncomingProtocol::IMAP },
            {   46, IncomingProtocol::POP3 },
            {   47, IncomingProtocol::KOLAB },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AccountConfiguration, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN20AccountConfigurationE[] = {
    QMetaObject::SuperData::link<MailTransport::Transport::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject AccountConfiguration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AccountConfigurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AccountConfigurationE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN20AccountConfigurationE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20AccountConfigurationE_t>.metaTypes,
    nullptr
} };

void AccountConfiguration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountConfiguration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->passwordChanged(); break;
        case 1: _t->emailChanged(); break;
        case 2: _t->identityChanged(); break;
        case 3: _t->configurationIsValidChanged(); break;
        case 4: _t->incomingHostNameChanged(); break;
        case 5: _t->incomingPortChanged(); break;
        case 6: _t->incomingUserNameChanged(); break;
        case 7: _t->incomingProtocolChanged(); break;
        case 8: _t->incomingSecurityProtocolChanged(); break;
        case 9: _t->incomingAuthenticationProtocolChanged(); break;
        case 10: _t->disconnectedModeEnabledChanged(); break;
        case 11: _t->hasDisconnectedModeChanged(); break;
        case 12: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->finished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->serverTestInProgressModeChanged(); break;
        case 16: _t->save((*reinterpret_cast<std::add_pointer_t<ConsoleLog*>>(_a[1]))); break;
        case 17: _t->checkServer(); break;
        case 18: _t->checkConfiguration(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::passwordChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::emailChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::identityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::configurationIsValidChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::incomingHostNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::incomingPortChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::incomingUserNameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::incomingProtocolChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::incomingSecurityProtocolChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::incomingAuthenticationProtocolChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::disconnectedModeEnabledChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::hasDisconnectedModeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)(const QString & )>(_a, &AccountConfiguration::error, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)(const QString & )>(_a, &AccountConfiguration::info, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)(const QString & )>(_a, &AccountConfiguration::finished, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfiguration::*)()>(_a, &AccountConfiguration::serverTestInProgressModeChanged, 15))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KIdentityManagementCore::Identity >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MailTransport::Transport* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<MailTransport::Transport**>(_v) = _t->mailTransport(); break;
        case 1: *reinterpret_cast<KIdentityManagementCore::Identity*>(_v) = _t->identity(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->password(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->email(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->incomingHostName(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->incomingPort(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->incomingUserName(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->mConfigurationIsValid; break;
        case 8: *reinterpret_cast<enum IncomingProtocol*>(_v) = _t->incomingProtocol(); break;
        case 9: *reinterpret_cast<MailTransport::Transport::EnumEncryption*>(_v) = _t->incomingSecurityProtocol(); break;
        case 10: *reinterpret_cast<MailTransport::Transport::EnumAuthenticationType*>(_v) = _t->incomingAuthenticationProtocol(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->disconnectedModeEnabled(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->mHasDisconnectedMode; break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->mServerTestInProgress; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setIdentity(*reinterpret_cast<KIdentityManagementCore::Identity*>(_v)); break;
        case 2: _t->setPassword(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setEmail(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setIncomingHostName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setIncomingPort(*reinterpret_cast<uint*>(_v)); break;
        case 6: _t->setIncomingUserName(*reinterpret_cast<QString*>(_v)); break;
        case 7:
            if (QtMocHelpers::setProperty(_t->mConfigurationIsValid, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->configurationIsValidChanged();
            break;
        case 8: _t->setIncomingProtocol(*reinterpret_cast<enum IncomingProtocol*>(_v)); break;
        case 9: _t->setIncomingSecurityProtocol(*reinterpret_cast<MailTransport::Transport::EnumEncryption*>(_v)); break;
        case 10: _t->setIncomingAuthenticationProtocol(*reinterpret_cast<MailTransport::Transport::EnumAuthenticationType*>(_v)); break;
        case 11: _t->setDisconnectedModeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 12:
            if (QtMocHelpers::setProperty(_t->mHasDisconnectedMode, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->hasDisconnectedModeChanged();
            break;
        case 13:
            if (QtMocHelpers::setProperty(_t->mServerTestInProgress, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->serverTestInProgressModeChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *AccountConfiguration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccountConfiguration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AccountConfigurationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AccountConfiguration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void AccountConfiguration::passwordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AccountConfiguration::emailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AccountConfiguration::identityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AccountConfiguration::configurationIsValidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AccountConfiguration::incomingHostNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AccountConfiguration::incomingPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AccountConfiguration::incomingUserNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AccountConfiguration::incomingProtocolChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AccountConfiguration::incomingSecurityProtocolChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AccountConfiguration::incomingAuthenticationProtocolChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AccountConfiguration::disconnectedModeEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AccountConfiguration::hasDisconnectedModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AccountConfiguration::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void AccountConfiguration::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void AccountConfiguration::finished(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void AccountConfiguration::serverTestInProgressModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
