/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<accountconfiguration.h>)
#  include <accountconfiguration.h>
#endif
#if __has_include(<configurationmodel.h>)
#  include <configurationmodel.h>
#endif
#if __has_include(<consolelog.h>)
#  include <consolelog.h>
#endif
#if __has_include(<foreigntypes.h>)
#  include <foreigntypes.h>
#endif
#if __has_include(<setupmanager.h>)
#  include <setupmanager.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_pim_accountwizard()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AccountConfiguration>("org.kde.pim.accountwizard", 1);
    qmlRegisterEnum<AccountConfiguration::IncomingProtocol>("AccountConfiguration::IncomingProtocol");
    qmlRegisterTypesAndRevisions<ConfigurationModel>("org.kde.pim.accountwizard", 1);
    qmlRegisterTypesAndRevisions<ConsoleLog>("org.kde.pim.accountwizard", 1);
    qmlRegisterEnum<ConsoleLog::EntryType>("ConsoleLog::EntryType");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<SetupManager>("org.kde.pim.accountwizard", 1);
    qmlRegisterTypesAndRevisions<Transport>("org.kde.pim.accountwizard", 1);
    QMetaType::fromType<Transport *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.pim.accountwizard", 1, 0);
}

static const QQmlModuleRegistration orgkdepimaccountwizardRegistration("org.kde.pim.accountwizard", qml_register_types_org_kde_pim_accountwizard);
