/****************************************************************************
** Meta object code from reading C++ file 'setupmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmail-account-wizard-26.07.90/src/setupmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'setupmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12SetupManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto SetupManager::qt_create_metaobjectdata<qt_meta_tag_ZN12SetupManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SetupManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "fullNameChanged",
        "",
        "emailChanged",
        "passwordChanged",
        "searchIspdbFoundMessageChanged",
        "noConfigFoundChanged",
        "detailsChanged",
        "searchConfiguration",
        "email",
        "password",
        "fullName",
        "configurationModel",
        "ConfigurationModel*",
        "searchIspdbFoundMessage",
        "noConfigFound",
        "details"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fullNameChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emailChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchIspdbFoundMessageChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noConfigFoundChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'detailsChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'searchConfiguration'
        QtMocHelpers::MethodData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'email'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'password'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'fullName'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'configurationModel'
        QtMocHelpers::PropertyData<ConfigurationModel*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'searchIspdbFoundMessage'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'noConfigFound'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'details'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SetupManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SetupManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SetupManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SetupManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12SetupManagerE_t>.metaTypes,
    nullptr
} };

void SetupManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SetupManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fullNameChanged(); break;
        case 1: _t->emailChanged(); break;
        case 2: _t->passwordChanged(); break;
        case 3: _t->searchIspdbFoundMessageChanged(); break;
        case 4: _t->noConfigFoundChanged(); break;
        case 5: _t->detailsChanged(); break;
        case 6: _t->searchConfiguration(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SetupManager::*)()>(_a, &SetupManager::fullNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SetupManager::*)()>(_a, &SetupManager::emailChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SetupManager::*)()>(_a, &SetupManager::passwordChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SetupManager::*)()>(_a, &SetupManager::searchIspdbFoundMessageChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SetupManager::*)()>(_a, &SetupManager::noConfigFoundChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SetupManager::*)()>(_a, &SetupManager::detailsChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ConfigurationModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->email(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->password(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->fullName(); break;
        case 3: *reinterpret_cast<ConfigurationModel**>(_v) = _t->configurationModel(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->mSearchIspdbFoundMessage; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->mNoConfigFound; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->details(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEmail(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPassword(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setFullName(*reinterpret_cast<QString*>(_v)); break;
        case 4:
            if (QtMocHelpers::setProperty(_t->mSearchIspdbFoundMessage, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->searchIspdbFoundMessageChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->mNoConfigFound, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->noConfigFoundChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *SetupManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SetupManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SetupManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SetupManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void SetupManager::fullNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SetupManager::emailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SetupManager::passwordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SetupManager::searchIspdbFoundMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SetupManager::noConfigFoundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SetupManager::detailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
